@@ -3,7 +3,7 @@ from click.testing import CliRunner
 from cli_template import cli
 
 
-def test_search():
+def test_cli():
     runner = CliRunner()
     result = runner.invoke(cli, ["initdb"])
     assert result.exit_code == 0
